package org.example.wedding_app_backend.controller;

import lombok.extern.java.Log;
import org.example.wedding_app_backend.controller.representation.GetWeddingImagesResponse;
import org.example.wedding_app_backend.function.RequestToWeddingImageFunction;
import org.example.wedding_app_backend.function.WeddingImagesToResponseFunction;
import org.example.wedding_app_backend.repository.entity.WeddingImage;
import org.example.wedding_app_backend.service.WeddingImageService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.server.ResponseStatusException;

import java.util.Map;
import java.util.UUID;

@RequestMapping("/api/wedding")
@RestController
@Log
public class WeddingImageController {
    private final WeddingImageService weddingImageService;

    private final WeddingImagesToResponseFunction weddingImagesToResponse;
    private final RequestToWeddingImageFunction requestToWeddingImage;

    @Autowired
    public WeddingImageController(
            WeddingImageService weddingImageService,
            RequestToWeddingImageFunction requestToWeddingImage,
            WeddingImagesToResponseFunction weddingImagesToResponse) {
        this.weddingImageService = weddingImageService;
        this.requestToWeddingImage = requestToWeddingImage;
        this.weddingImagesToResponse = weddingImagesToResponse;
    }

    @GetMapping("{weddingId}/gallery")
    public ResponseEntity<GetWeddingImagesResponse> getWeddingGallery(
            @PathVariable("weddingId") UUID weddingId,
            @RequestParam(value = "sort", required = false) String sort)
    {
        return weddingImageService.findAllWeddingImages(weddingId, sort)
                .map(weddingImagesToResponse)
                .map(ResponseEntity::ok)
                .orElse(ResponseEntity.notFound().build());
    }

    @GetMapping(path = "{weddingId}/gallery/{id}", produces = MediaType.IMAGE_JPEG_VALUE)
    @ResponseStatus(HttpStatus.OK)
    @ResponseBody
    public byte[] getWeddingImage(@PathVariable("weddingId") UUID weddingId, @PathVariable("id") UUID id) {
        return weddingImageService.findWeddingImage(id)
                .map(WeddingImage::getImage)
                .orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND));
    }

    @PostMapping(path = "{weddingId}/gallery/add", consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    @ResponseStatus(HttpStatus.CREATED)
    public void putWeddingImage(@PathVariable("weddingId") UUID weddingId, @RequestParam("image") MultipartFile request) {
        weddingImageService.saveWeddingImage(requestToWeddingImage.apply(weddingId, request));
    }

    @PatchMapping(path = "{weddingId}/gallery/{imageId}")
    @ResponseStatus(HttpStatus.OK)
    public void changeWeddingImageLikes(@PathVariable("weddingId") UUID weddingId, @PathVariable("imageId") UUID imageId, @RequestBody Map<String, Integer> payload)
    {
        weddingImageService.findWeddingImage(imageId)
                .ifPresentOrElse(
                        character -> {
                            weddingImageService.updateLikes(imageId, payload.get("like"));
                        },
                        () -> {
                            throw new ResponseStatusException(HttpStatus.NOT_FOUND);
                        }
                );
    }
}
