package org.example.wedding_app_backend.initializer;

import lombok.RequiredArgsConstructor;
import org.example.wedding_app_backend.repository.entity.WeddingEntity;
import org.example.wedding_app_backend.repository.entity.WeddingImage;
import org.example.wedding_app_backend.service.WeddingImageService;
import org.example.wedding_app_backend.service.WeddingService;
import org.springframework.beans.factory.InitializingBean;
import org.springframework.stereotype.Component;

import java.io.IOException;
import java.io.InputStream;
import java.time.LocalDateTime;
import java.util.UUID;

@Component
@RequiredArgsConstructor
public class DataInitializer implements InitializingBean {

    private final WeddingService weddingService;

    private final WeddingImageService weddingImageService;

    @Override
    public void afterPropertiesSet() throws IOException {
        WeddingEntity wedding = WeddingEntity.builder()
                .id(UUID.fromString("123e4567-e89b-12d3-a456-426614174000"))
                .name("MATIEGO i KUBUSIA")
                .build();
        weddingService.save(wedding);

        WeddingImage weddingImage1 = WeddingImage.builder()
                .id(UUID.randomUUID())
                .likes(0)
                .date(LocalDateTime.now())
                .wedding(wedding)
                .image(readImageAsByteArray("IMG_1.jpeg"))
                .build();
        weddingImageService.saveWeddingImage(weddingImage1);

        WeddingImage weddingImage2 = WeddingImage.builder()
                .id(UUID.randomUUID())
                .likes(0)
                .date(LocalDateTime.now())
                .wedding(wedding)
                .image(readImageAsByteArray("IMG_2.jpeg"))
                .build();
        weddingImageService.saveWeddingImage(weddingImage2);

        WeddingImage weddingImage3 = WeddingImage.builder()
                .id(UUID.randomUUID())
                .likes(0)
                .date(LocalDateTime.now())
                .wedding(wedding)
                .image(readImageAsByteArray("IMG_3.jpeg"))
                .build();
        weddingImageService.saveWeddingImage(weddingImage3);
    }

    private byte[] readImageAsByteArray(String name) throws IOException {
        try (InputStream is = this.getClass().getResourceAsStream("/images/" + name)) {
            return is.readAllBytes();
        }
    }

}
