package org.example.wedding_app_backend.service;

import org.example.wedding_app_backend.repository.entity.WeddingImage;
import org.example.wedding_app_backend.repository.WeddingImageRepository;
import org.example.wedding_app_backend.repository.WeddingRepository;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Sort;
import org.springframework.stereotype.Service;

import java.util.List;
import java.util.Optional;
import java.util.UUID;

@Service
public class WeddingImageService {

    private final WeddingImageRepository weddingImageRepository;
    private final WeddingRepository weddingRepository;

    @Autowired
    public WeddingImageService(
            WeddingImageRepository repository,
            WeddingRepository weddingRepository) {
        this.weddingImageRepository = repository;
        this.weddingRepository = weddingRepository;
    }

    public Optional<WeddingImage> findWeddingImage(UUID id) {
        return weddingImageRepository.findById(id);
    }

    public void saveWeddingImage(WeddingImage weddingImage) {
        weddingImageRepository.save(weddingImage);
    }

    public Optional<List<WeddingImage>> findAllWeddingImages(UUID weddingId, String sort) {
        if (sort != null) {
            return weddingRepository.findById(weddingId)
                    .map(wedding -> weddingImageRepository.findAllByWedding(wedding, Sort.by(Sort.Order.desc(sort))));
        } else {
            return weddingRepository.findById(weddingId)
                    .map(weddingImageRepository::findAllByWedding);
        }
    }

    public void updateLikes(UUID weddingImageId, int like) {
        weddingImageRepository.findById(weddingImageId).ifPresent(weddingImage -> {
            weddingImage.setLikes(weddingImage.getLikes() + like);
            weddingImageRepository.save(weddingImage);
        });
    }
}
