import {Component, OnInit, signal, WritableSignal} from '@angular/core';
import {ActivatedRoute, NavigationEnd, Router} from '@angular/router';
import {TabMenuModule} from 'primeng/tabmenu';
import {MenuItem} from 'primeng/api';

@Component({
  selector: 'app-nav',
  standalone: true,
  templateUrl: './nav.component.html',
  imports: [
    TabMenuModule
  ],
  styleUrl: './nav.component.css'
})
export class NavComponent implements OnInit {

  constructor(private router: Router, private route: ActivatedRoute) {
  }

  weddingId: WritableSignal<string | null> = signal<string | null>(null);
  items: Array<MenuItem> = [
    {
      icon: 'fa-solid fa-home',
      label: 'Home',
      command: () => {
        this.router.navigate(['/wedding', this.weddingId()]);
      }
    },
    {
      icon: 'fa-solid fa-images',
      label: 'Gallery',
      command: () => {
        this.router.navigate(['/wedding', this.weddingId(), 'gallery']);
      }
    },
    {
      icon: 'fa-solid fa-gamepad',
      label: 'Games',
      command: () => {
        this.router.navigate(['/wedding', this.weddingId(), 'games']);
      }
    }]

  ngOnInit(): void {
    this.router.events.subscribe(event => {
      if (event instanceof NavigationEnd) {
        this.weddingId.set(this.route.firstChild?.snapshot.params['id']);
        console.log('Wedding ID:', this.weddingId());
      }
    });
  }

}
